"""Fixtures/Test data is placed in this file."""

BBOB_2D_PER_MODULE_20_ITER = {
    "active_True": [
        79.60870540043959,
        -6.834740339081748,
        -446.942231900092,
        -453.1166279102467,
        12.91474629678331,
        2057.8823697805324,
        93.54091559010935,
        149.29454116123992,
        123.88066647543144,
        6731.6154970887155,
        102443.81430369585,
        643625.010286943,
        45.175034363167605,
        -52.01531942754774,
        1017.3030673363197,
        79.03702012530019,
        11.753343447706664,
        131.38805502911111,
        -102.10176326857986,
        -543.6999174336394,
        42.700744146686965,
        -999.9997057338787,
        8.695689533892846,
        117.29640024093563,
    ],
    "base_sampler_gaussian": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "base_sampler_halton": [
        79.48077842021073,
        136.53129100639717,
        -446.7506458965296,
        -446.87082153002194,
        11.950884905405736,
        5329.481213692499,
        93.0361464944175,
        149.71900030510446,
        124.02881103802382,
        70984.29907315908,
        1122036.1339262475,
        323500.4088727226,
        40.771980667227886,
        -51.48698849157431,
        1020.9436930982043,
        78.05502682158907,
        -4.961694831220257,
        157.23783058587483,
        -102.30221897973205,
        -543.7781557151272,
        42.67339847137175,
        -999.9963011818812,
        14.73597350603703,
        124.02200389471975,
    ],
    "base_sampler_sobol": [
        79.58776048088133,
        3422.226350474581,
        -445.62619936885244,
        -452.131564688653,
        7.17122029401677,
        42.96515961182474,
        93.45715847183976,
        149.54498657058198,
        126.88596518033647,
        298.42477393412827,
        1365728.4147451057,
        48635.303416026385,
        48.505871726336075,
        -51.74059898989086,
        1016.9939691575535,
        72.24266434815569,
        -2.605200628010161,
        169.34805329384733,
        -102.5486907676662,
        -543.3053885969988,
        42.781850042137705,
        -999.9962323826467,
        12.046411510472002,
        107.7143392718549,
    ],
    "bound_correction_COTN": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "bound_correction_mirror": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "bound_correction_saturate": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "bound_correction_toroidal": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "bound_correction_unif_resample": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "elitist_True": [
        79.58359771151284,
        3722.3761689261983,
        -444.6996743229732,
        -449.63233155751726,
        11.403773075168843,
        1938.1349061808248,
        93.54091559010935,
        149.72424316023083,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        338749.1203340543,
        43.368771569040824,
        -51.8908644736279,
        1017.567313102047,
        82.16884108988424,
        5.9547855849801365,
        1.4811701439965574,
        -102.1160727430898,
        -543.698445859984,
        42.60165481703265,
        -999.9991133679798,
        9.843395190328877,
        111.69367145373013,
    ],
    "local_restart_BIPOP": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "local_restart_IPOP": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "mirrored_mirrored pairwise": [
        79.49271732413378,
        -3.9902436014381237,
        -449.9527094090616,
        -453.43140996395596,
        -5.716753396809776,
        38.656680881133425,
        93.54091559010935,
        149.66006205975523,
        124.3073642920228,
        496.9430991621704,
        5774.525239039822,
        10810.490466468276,
        65.01376333683325,
        -52.14160901603763,
        1012.9356025505306,
        79.37035747661811,
        -0.08086837288995241,
        -7.360624274953013,
        -102.5420591790735,
        -545.1782424507006,
        42.700744146686965,
        -999.9999959402685,
        11.36066981667674,
        120.60256772763952,
    ],
    "mirrored_mirrored": [
        79.49271732413378,
        -3.9902436014381237,
        -449.43912237059925,
        -454.76923415255794,
        -5.716753396809776,
        38.656680881133425,
        92.96068633887359,
        149.4276007295378,
        124.29995348854516,
        496.9430991621704,
        5774.525239039822,
        10810.490466468276,
        65.01376333683325,
        -52.14160901603763,
        1016.7839906734483,
        77.37715351910123,
        -0.08317538023811721,
        71.41166512690214,
        -101.99373657488567,
        -545.1782424507006,
        42.700744146686965,
        -999.5409569330642,
        16.018941166090844,
        118.76164430789493,
    ],
    "orthogonal_True": [
        80.07173193213463,
        -25.0810474775418,
        -448.44029337005736,
        -450.2217227339582,
        17.131150531337912,
        104768.75359048153,
        92.94000013395934,
        149.41567464975682,
        125.54323736579038,
        1949380.8182024239,
        7892515.3458270915,
        1608304.8817702506,
        75.99337230697218,
        -50.85961901646829,
        1013.0164228422623,
        76.63491974976154,
        15.945556157304662,
        218.11413710292456,
        -102.47909541110062,
        -543.8195887825041,
        42.93989939186737,
        -970.8073891259909,
        13.673346703024826,
        119.86000340058254,
    ],
    "sequential_True": [
        83.26223403453476,
        117512.71823407112,
        -443.0425148340509,
        -449.63233155751726,
        23.133202262711286,
        10389.813539761111,
        97.60995333434538,
        149.3343488478487,
        127.59393177390666,
        7694330.796085853,
        17017375.25140306,
        4597655.93725784,
        76.81564795511831,
        -47.55613893161405,
        1025.8209383489839,
        77.72987263145716,
        7.988026029647063,
        73.98356807373503,
        -100.19493286681244,
        -544.9528467594567,
        42.700744146686965,
        -999.39715508158,
        18.64162794684728,
        121.36057695184782,
    ],
    "step_size_adaptation_csa": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "step_size_adaptation_lp-xnes": [
        79.60059107122254,
        1156.2973035672185,
        -444.90820695481506,
        -448.94358552780955,
        -36.4848051463744,
        8358.025517299127,
        92.9460091559011,
        149.7493269470448,
        124.04952799814593,
        2621.0381521404584,
        1495208.493849278,
        5626.592106895178,
        62.31859253339392,
        -52.32649247097711,
        1010.1744131780363,
        72.09734755535143,
        -15.912959021956848,
        32.30960255054117,
        -102.34645248406176,
        -544.3080167220543,
        42.749007493000086,
        -999.7029654400319,
        22.669115494695657,
        113.67506020056967,
    ],
    "step_size_adaptation_m-xnes": [
        79.55906633738796,
        4386.41620419817,
        -440.14992398127674,
        -460.98138016361116,
        16.40228675582609,
        41.770782199901596,
        93.54091559010935,
        149.3001510889701,
        123.88066647543144,
        18684.968308009655,
        128482.83441910103,
        1281857.3005289235,
        44.362127255980496,
        -50.98280710710338,
        1017.7040292314994,
        71.81002578700317,
        -14.500528708427396,
        -6.233462492224653,
        -102.10176326857986,
        -544.1923846845665,
        42.700744146686965,
        -999.9963799088132,
        9.561553063179554,
        112.87464428268412,
    ],
    "step_size_adaptation_msr": [
        79.54244003306202,
        -118.26581009548049,
        -440.14992398127674,
        -455.4835960403074,
        18.736041419360657,
        3605.4061633764236,
        93.54091559010935,
        149.26601857625818,
        123.88066647543144,
        -21.626275737512415,
        58043.62661894809,
        2620394.1433755127,
        44.362127255980496,
        -51.667675482694605,
        1017.7040292314994,
        72.26712789062267,
        -7.438752386989677,
        15.992223171740047,
        -102.10176326857986,
        -543.8534185721645,
        42.700744146686965,
        -999.9068914798465,
        9.561553063179554,
        112.57452019629068,
    ],
    "step_size_adaptation_psr": [
        79.52102181383879,
        -43.91160560551333,
        -441.11726502191607,
        -456.56128813648616,
        17.849839938781177,
        3694.7014049597274,
        93.54091559010935,
        149.26690941710297,
        123.88066647543144,
        1913.6658308753742,
        148364.03186841556,
        2676492.5753466967,
        44.362127255980496,
        -51.62579424252932,
        1017.7040292314994,
        72.30933289942361,
        -14.511086097928466,
        43.86640712845018,
        -102.10176326857986,
        -544.024382872537,
        42.700744146686965,
        -999.945912328108,
        9.561553063179554,
        112.87464428268412,
    ],
    "step_size_adaptation_tpa": [
        79.55308020971381,
        -207.50259603890402,
        -440.14992398127674,
        -458.57288088617247,
        5.4741183447131725,
        6560.528235059466,
        93.54091559010935,
        149.65559838973334,
        123.87243680449797,
        233.45934327394536,
        1016974.9297563785,
        23982.268064532716,
        79.31957554796386,
        -51.0613012456259,
        1017.7040292314994,
        74.72824129498854,
        2.558947945699611,
        83.81239421766517,
        -102.15624729506743,
        -543.8204123260658,
        42.65562681704674,
        -999.8888868157063,
        15.715875189059393,
        113.50420157724996,
    ],
    "step_size_adaptation_xnes": [
        79.52868923287008,
        177.2921188004035,
        -446.3366142028796,
        -457.76830870934236,
        7.460165563308379,
        458.5247153830321,
        93.54091559010935,
        149.45732280899628,
        123.88066647543144,
        326.56650297189964,
        86.90556172988374,
        267979.67340446153,
        77.00389803635447,
        -52.16277774524084,
        1017.5812992339265,
        74.05900952761623,
        -1.0401150483872836,
        -15.049763678473477,
        -102.19153553838316,
        -544.0421116229078,
        42.700744146686965,
        -999.7036847182642,
        16.574926415489365,
        117.94855761761136,
    ],
    "threshold_convergence_True": [
        79.5493946792015,
        -205.8874080989055,
        -440.3860520213715,
        -454.59404450938604,
        11.02595182176956,
        747.5617626591987,
        93.54091559010935,
        149.20184452013788,
        125.29702895733809,
        9842.867547245534,
        25856.991912239057,
        15020.589468025295,
        43.368771569040824,
        -52.317831132167846,
        1025.8209383489839,
        75.65775413626635,
        -15.694063684846274,
        -6.053852018150245,
        -101.94712477091193,
        -544.8856238640917,
        42.68657509138354,
        -999.9820990897024,
        11.66582534228891,
        117.58369741868964,
    ],
    "weights_option_1/2^lambda": [
        79.5630351924981,
        4629.283234379299,
        -440.14992398127674,
        -458.5322418694519,
        17.401736662231777,
        2171.3837540807126,
        93.54091559010935,
        149.3215688070224,
        123.88066647543144,
        4775.304616031011,
        2485.875547646586,
        2552406.7655545343,
        57.15312947598912,
        -51.89261437835274,
        1017.7040292314994,
        73.89054993912737,
        -12.20385658566134,
        9.78378595249066,
        -102.15555135313454,
        -543.698445859984,
        42.700744146686965,
        -999.9821332012928,
        18.573719726473,
        111.84525007583429,
    ],
    "weights_option_default": [
        79.60197400323416,
        9075.81294241299,
        -443.0425148340509,
        -449.63233155751726,
        15.221583968074889,
        1938.1349061808248,
        93.54091559010935,
        149.27592202799931,
        123.88066647543144,
        7116.932319384926,
        335648.9894252748,
        1407321.3639251885,
        43.368771569040824,
        -52.116212719435566,
        1017.7040292314994,
        72.00354123874057,
        7.140121147903702,
        34.24774851152607,
        -102.24646124346252,
        -543.698445859984,
        42.700744146686965,
        -999.8961680110624,
        13.582863728801364,
        116.76955516252966,
    ],
    "weights_option_equal": [
        79.4841795554343,
        -206.93295112420896,
        -446.8074233371284,
        -445.1350192190321,
        21.06207513561158,
        46.678137440267065,
        93.54091559010935,
        149.56940870119797,
        123.86194759511636,
        29972.293198196898,
        361029.7991199966,
        7697201.177123937,
        89.58749452760148,
        -51.4644595745646,
        1017.7040292314994,
        77.27755720351972,
        -10.054973805866888,
        12.496064113477054,
        -102.10176326857986,
        -543.7171538434422,
        42.677106643653936,
        -999.99941581072,
        14.937956237333932,
        115.99850936925196,
    ],
}